/*
 *      Program do przegladania logow z ekg.
 *
 *
 *      copyright (c) 2003 by Lukasz Bartnik
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __CMD_HELP_HH__
#define __CMD_HELP_HH__


#include "command-base.h"
#include "texts.h"

/**
 * @brief Klawisz f2.
 */
class cmd_help_t : public command_base_t {
public:

	cmd_help_t() :  command_base_t("help"),
			_help_short(HELP_HELP_SHORT),
			_help_long(HELP_HELP_LONG)
	{}

	void run(const std::vector<std::string> & argv)
	{
		// ilosc spacji okreslona jest przez command_base_t::max_size
		std::string spaces = "          ";

		if(!argv.size()) {
		    std::string help(HELP_SHORT_BEGIN);

			// zbieramy krotka pomoc dla wszystkich komend i wyswietlamy razem
			for(std::map<std::string, command_base_t*>::iterator i=_cmds->begin();
				i!=_cmds->end(); ++i)
			{
				if(i->second->help_short().size()) {
					help += "\\c710";
					help += i->second->name();
					help += "\\d";
					help += spaces.substr(0, 10-i->second->name().size());
					help += "-  ";
					help += i->second->help_short();
					help += "\n";
				}
			}

			help += HELP_SHORT_END;

			_info->print(help.c_str(), ALL_HELP_FMT);
		}
		else if(argv.size() == 1) {

			// znajdujemy komende, dla ktorej pomoc ma byc wyswietlona
			for(std::map<std::string, command_base_t*>::iterator i=_cmds->begin();
				i!=_cmds->end(); ++i)
			{
				if (i->second->name() == argv[0]) {
					_info->print( (i->second->help_long()).c_str(),
						 ALL_HELP_FMT);
					return;
				}
			}

			std::string tmp = HELP_WRONG_COMMAND + argv[0];
			_info->print(tmp.c_str(), ALL_HELP_FMT);
		}
		else {
			_info->print(HELP_TOO_MANY_ARGS, ALL_HELP_FMT);
		}
	} // run()


	virtual const std::vector<std::string> & completition_lvl2()
	{
		if (_first_time)
			build_completition();

		return _completition;
	}

	virtual const std::string & help_short()
	{
		return _help_short;
	}

	virtual const std::string & help_long()
	{
		return _help_long;
	}


private:

	/// przygotowuje tablice argumentow
	void build_completition()
	{
		_first_time = false;

		// zbieramy wszystkie komendy, ktore maja dostepna pomoc
		for(std::map<std::string, command_base_t*>::iterator i=_cmds->begin();
			i!=_cmds->end(); ++i)
		{
			if(i->second->help_short().size()) {
				_completition.push_back(i->second->name());
			}
		}
	}

	std::vector<std::string> _completition;
	std::string _help_short, _help_long;
	/// czy zbudowano juz tablice mozliwych argumentow
	bool _first_time;
};

#endif /* __CMD_HELP_HH__ */
