/*
 *      Program do przegladania logow z ekg.
 *      Komenda scalania logow.
 *
 *      copyright (c) 2003 by Lukasz Bartnik
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __CMD_MERGE_HH__
#define __CMD_MERGE_HH__

#include <fstream>

#include "command-base.h"
#include "texts.h"

/**
 * @brief Komenda quit
 */
class cmd_merge_t : public command_base_t {
public:

	cmd_merge_t() :  command_base_t("merge"),
			_help_short(HELP_MERGE_SHORT),
			_help_long(HELP_MERGE_LONG)
	{
	}

	void run(const std::vector<std::string> & argv)
	{
		using namespace std;

		if(argv.size() != 2) {
			_info->print(MERGE_ERROR_ARGS, ALL_ERROR_FMT);
			return;
		}

		if (argv[1] == "dir") {
			return;
		}
		if (argv[0] == "file") {
			ifstream in(argv[0].c_str());
			if (!in) {
				_info->print(MERGE_WRONG_PATH, ALL_ERROR_FMT);
				return;
			}
			_db->merge(argv[0], dBase::FILE);
			return;
		}
		_info->print(MERGE_WRONG_TYPE, ALL_ERROR_FMT);
	} // run()


	virtual const std::vector<std::string> & completition_lvl2()
	{
		return _completition;
	}

	virtual const std::string & help_short()
	{
		return _help_short;
	}

	virtual const std::string & help_long()
	{
		return _help_long;
	}


private:

	std::vector<std::string> _completition;
	std::string _help_short, _help_long;
};

#endif /* __CMD_MERGE_HH__ */
