/*
 *      Program do przegladania logow z ekg.
 *      Klasa podstawowa okna.
 *
 *
 *      copyright (c) 2003 by Lukasz Bartnik
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef __WINDOW_HH__
#define __WINDOW_HH__

#include <string>
#include <vector>

extern "C" {
	#include <ncurses.h>
}

#include "line.h"
#include "stuff.h"

class window_t {
public:
	window_t(const char *title, 
		int width, int height,
		int margin_top, int margin_bottom, int margin_left, int margin_right,
		int fg, int bold, int bg,
		WINDOW *win=0,
		bool cut_out=false);

	virtual ~window_t() {}

	/// podswietl pasek tytulu
	void set_active(void) { _act = true; _redraw = true; }
	/// przyciemnij pasek tytulu
	void set_passive(void) { _act = false; _redraw = true; }
	/// informuje, czy okno jest aktywne
	bool is_active() { return _act; }
	/// Wypisuje zawartosc okna na ekran.
	virtual void print();
	/// Dodaje tekst do okna.
	void print(const std::string & str, const std::string & fmt = "", bool message=false);
	/// Ustawia okno ncurses do wyswietlania.
	void setwindow(WINDOW *win) { _win = win; }
	/// Informuje, czy w oknie jest cos, co nie bylo jeszcze wypisywane.
	bool has_new() { return _has_new; }
	/// zwraca ilosc linii dostepnych na tresc okna
	unsigned int vsize(void) { return _height - _margin_top - _margin_bottom; }
	/// zwraca ilosc kolumn dostepnych na tresc okna
	unsigned int hsize(void) { return _width - _margin_left - _margin_right; }
	
	/// Przesuwanie zawartosci okna.
	virtual void moveup();
	virtual void movedown();
	virtual void movepgup();
	virtual void movepgdown();

protected:

	/// Dodaje do tresci okna nowa linie.
	void addline(const std::string & str, unsigned int cut=0);
	/// Czyszczenie zawartosci okna.
	void clear();


	/// okno ncurses
	WINDOW *_win;
	/// wymiary okna
	unsigned int _width, _height;
	/// marginesy dla teksty w oknie
	unsigned int _margin_top, _margin_bottom, _margin_left, _margin_right;
	/// domyslne kolory okna
	int _fg, _bold, _bg;
	/// tresc paska tytulu
	std::string _title;
	/// czy okno nalezy przerysowac
	bool _redraw;
	/// czy pasek okna jest aktywny
	bool _act;
	/// czy w oknie sa linie dotychczas nie wypisywane
	bool _has_new;
	/// numer linii od ktorej zaczynac wypisywanie
	unsigned int _screen_start;
	/// tresc okna - lista linii
	std::vector<line_t> _lines;

	/// wycinanie znakow z wiadomosci
	/// czy wycinac znaki "\\r" i "\\n" i zapamietywac ilosc wycietych w linii znakow
	bool _cut_out;
	std::vector<unsigned int> _cut;
};

#endif /* __WINDOW_HH__ */
