/*
 *      Program do przegladania logow z ekg.
 *      Klasa okna - listy wyboru.
 *
 *
 *      copyright (c) 2003 by Lukasz Bartnik
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "winlist.h"
#include <algorithm>


winlist_t::winlist_t(const char *title, 
		int width, int height,
		WINDOW *win)
	: window_t(title, width, height, 0,0,1,0, COLOR_GREEN, 1, COLOR_BLACK, win),
	    _chosen_line(0)
{
	if (title)
		_title_part = title;
}


void winlist_t::print()
{
	if(!_redraw)
		return;

	window_t::print();

	/* wypisujemy wybrana linie */
	if (_lines.size()) {
		unsigned int chosen = _chosen_line - _screen_start;
		wmove(_win, _margin_top + chosen, _margin_left);
		wattron(_win, color_pair(COLOR_YELLOW, 1, COLOR_BLACK));
		waddstr(_win, const_cast<char*>(_lines[_chosen_line].c_str()));
		wattroff(_win, color_pair(COLOR_YELLOW, 1, COLOR_BLACK));
	}

	/* a teraz dodanie linii pionowej + ponowne odswiezenie */
	wattron(_win, color_pair(COLOR_BLUE,0,0));
	wmove(_win, _margin_top, 0);
	wvline(_win, ACS_VLINE, hsize());
	wattroff(_win, color_pair(COLOR_BLUE,0,0));

	_redraw = false;
	wnoutrefresh(_win);
}


void winlist_t::moveup()
{
	if (_chosen_line > 0)
		--_chosen_line;

	set_screen_start();
}


void winlist_t::movedown()
{
	if (_chosen_line < _lines.size()-1)
		++_chosen_line;

	set_screen_start();
}


void winlist_t::movepgup()
{
	for(unsigned int i=0; i<vsize(); ++i)
		if (_chosen_line > 0)
			--_chosen_line;

	set_screen_start();
}


void winlist_t::movepgdown()
{
	for(unsigned int i=0; i<vsize(); ++i)
		if (_chosen_line < _lines.size()-1)
			++_chosen_line;

	set_screen_start();
}


void winlist_t::append(const std::string & str, int value)
{
	if(str.find('\n') != std::string::npos)
		return;

	_lines.push_back(line_t(str.substr(0, hsize()).c_str(), _fg, _bold, _bg));
	_line_values.push_back(value);
	_redraw = true;

	_title = _title_part + "(" + text_cast(_lines.size()) + ")";
}


int winlist_t::get_chosen_value()
{
	return _line_values[_chosen_line];
}


const std::string & winlist_t::get_chosen_str()
{
	return _lines[_chosen_line].str();
}


void winlist_t::set_screen_start()
{
	if (_lines.size() < vsize()) {
		_redraw = true;
		return;
	}
			
	if (_chosen_line < vsize()/2) {
		_screen_start = 0;
		_redraw = true;
		return;
	}

	if (_chosen_line > (_lines.size() - vsize()/2 - 1)) {
		_screen_start = _lines.size() - vsize();
		_redraw = true;
		return;
	}
											
	_screen_start = _chosen_line - vsize()/2;
	_redraw = true;
}


void winlist_t::clear()
{
	_lines.clear();
	_line_values.clear();
	_screen_start = 0;
	_chosen_line = 0;
	_redraw = true;
	_title = _title_part + "(0)";
}


void winlist_t::set_active_val(int val)
{
	std::vector<int>::iterator i = std::find(_line_values.begin(), _line_values.end(), val);

	_chosen_line = i-_line_values.begin();
	set_screen_start();
	_redraw = true;

}


winlist_t::const_iterator winlist_t::begin() const
{
	return _line_values.begin();
}


winlist_t::const_iterator winlist_t::end() const
{
	return _line_values.end();
}


winlist_t::const_iterator winlist_t::find(int val)
{
	return std::find(_line_values.begin(), _line_values.end(), val);
}


winlist_t::const_str_iterator winlist_t::str_begin() const
{
	return _lines.begin();
}


winlist_t::const_str_iterator winlist_t::str_end() const
{
	return _lines.end();
}


winlist_t::const_str_iterator winlist_t::str_find(std::string val)
{
	return std::find(_lines.begin(), _lines.end(), val);
}

